<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Form;

use Sylius\Bundle\ChannelBundle\Form\Type\ChannelChoiceType;
use Sylius\Bundle\ResourceBundle\Form\Type\AbstractResourceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints\Valid;

class ArticleType extends AbstractResourceType
{
    private string $authorClass;

    private string $articleTranslationClass;

    private string $categoryClass;

    private string $typeArticleClass;

    public function __construct(
        string $dataClass,
        string $authorClass,
        string $articleTranslationClass,
        string $categoryClass,
        string $typeArticleClass,
        array $validationGroups = [],
    ) {
        parent::__construct($dataClass, $validationGroups);

        $this->authorClass = $authorClass;
        $this->articleTranslationClass = $articleTranslationClass;
        $this->categoryClass = $categoryClass;
        $this->typeArticleClass = $typeArticleClass;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('enabled', CheckboxType::class, [
                'label' => 'dedi_blog.form.enabled',
            ])
            ->add('author', EntityType::class, [
                'class' => $this->authorClass,
                'multiple' => false,
                'choice_name' => 'username',
                'choice_value' => 'id',
                'by_reference' => false,
                'required' => false,
                'label' => 'dedi_blog.form.article.author',
            ])
            ->add('position', NumberType::class, [
                'html5' => true,
                'attr' => ['min' => 0, 'step' => 1],
                'label' => 'dedi_blog.form.article.position',
            ])
            ->add('banner', ArticleBannerType::class, [
                'required' => false,
                'label' => 'dedi_blog.form.article.banner',
            ])
            ->add('channels', ChannelChoiceType::class, [
                'multiple' => true,
                'expanded' => true,
                'label' => 'dedi_blog.form.channels',
            ])
            ->add('translations', ResourceTranslationsType::class, [
                'entry_type' => $this->articleTranslationClass,
                'constraints' => [new Valid()],
            ])

            ->add('categories', EntityType::class, [
                'class' => $this->categoryClass,
                'multiple' => true,
                'choice_name' => 'name',
                'choice_value' => 'id',
                'required' => false,
                'label' => 'dedi_blog.form.article.categories',
            ])

            ->add('type', EntityType::class, [
                'class' => $this->typeArticleClass,
                'required' => false,
                'label' => 'dedi_blog.ui.article_type',
            ])
        ;
    }
}
