<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Form;

use Sylius\Bundle\ChannelBundle\Form\Type\ChannelChoiceType;
use Sylius\Bundle\ResourceBundle\Form\Type\AbstractResourceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints\Valid;

class BlogConfigurationType extends AbstractResourceType
{
    private string $blogConfigurationTranslationType;

    public function __construct(
        string $dataClass,
        string $blogConfigurationTranslationType,
        array $validationGroups = [],
    ) {
        parent::__construct($dataClass, $validationGroups);

        $this->blogConfigurationTranslationType = $blogConfigurationTranslationType;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('channel', ChannelChoiceType::class, [
                'multiple' => false,
                'expanded' => true,
                'label' => 'dedi_blog.form.channel',
            ])
            ->add('headerDisplayable', CheckboxType::class, [
                'label' => 'dedi_blog.form.configuration.header_displayable',
            ])
            ->add('banner', BlogConfigurationBannerType::class, [
                'required' => false,
                'label' => 'dedi_blog.form.article.banner',
            ])
            ->add('translations', ResourceTranslationsType::class, [
                'entry_type' => $this->blogConfigurationTranslationType,
                'constraints' => [new Valid()],
            ])
        ;
    }
}
